package MooseX::AttributeHelpers::Collection::Hash;
use Moose;
use MooseX::AttributeHelpers::MethodProvider::Collection::Hash;

extends 'MooseX::AttributeHelpers::Collection';

our $VERSION   = '0.02';
our $AUTHORITY = 'cpan:STEVAN';

__PACKAGE__->sugar(
    method_provider  => 'Collection::Hash',
    shortcut         => 'Collection::Hash',
);

no Moose;

1;

__END__

=pod

=head1 NAME

MooseX::AttributeHelpers::Collection::Hash

=head1 SYNOPSIS

  package Stuff;
  use Moose;
  use MooseX::AttributeHelpers;
  
  has 'options' => (
      metaclass => 'Collection::Hash',
      is        => 'ro',
      isa       => 'HashRef[Str]',
      default   => sub { {} },
      provides  => {
          'set'    => 'set_option',
          'get'    => 'get_option',            
          'empty'  => 'has_options',
          'count'  => 'num_options',
          'delete' => 'delete_option',
      }
  );
  
=head1 DESCRIPTION

This module provides an Hash attribute which provides a number of 
hash-like operations. 

=head1 PROVIDED METHODS

The methods for this metaclass are provided by
L<MooseX::AttributeHelpers::MethodProvider::Collection::Hash>.

=head1 BUGS

All complex software has bugs lurking in it, and this module is no 
exception. If you find a bug please either email me, or add the bug
to cpan-RT.

=head1 AUTHOR

Stevan Little E<lt>stevan@iinteractive.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2007-2008 by Infinity Interactive, Inc.

L<http://www.iinteractive.com>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
