package MooseX::AttributeHelpers::Collection::ImmutableHash;
use Moose;
use MooseX::AttributeHelpers::MethodProvider::Collection::ImmutableHash;

our $VERSION   = '0.01';
our $AUTHORITY = 'cpan:STEVAN';

extends 'MooseX::AttributeHelpers::Collection';

__PACKAGE__->sugar(
    method_provider  => 'Collection::ImmutableHash',
    shortcut         => 'Collection::ImmutableHash',
);

no Moose;

1;

__END__

=pod

=head1 NAME

MooseX::AttributeHelpers::Collection::ImmutableHash

=head1 SYNOPSIS

  package Stuff;
  use Moose;
  use MooseX::AttributeHelpers;
  
  has 'options' => (
      metaclass => 'Collection::ImmutableHash',
      is        => 'ro',
      isa       => 'HashRef[Str]',
      default   => sub { {} },
      provides  => {
          'get'    => 'get_option',            
          'empty'  => 'has_options',
          'keys'   => 'get_option_list',
      }
  );
  
=head1 DESCRIPTION

This module provides a immutable HashRef attribute which provides a number of 
hash-like operations. 

=head1 PROVIDED METHODS

The methods for this metaclass are provided by
L<MooseX::AttributeHelpers::MethodProvider::Collection::ImmutableHash>.

=head1 BUGS

All complex software has bugs lurking in it, and this module is no 
exception. If you find a bug please either email me, or add the bug
to cpan-RT.

=head1 AUTHOR

Stevan Little E<lt>stevan@iinteractive.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2007-2008 by Infinity Interactive, Inc.

L<http://www.iinteractive.com>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
